@@ -6,6 +6,7 @@
 #' This can assist in gauging the optimal model from a set of options along with estimates of variance
 #' (through individual resampling iterations).
 #'
+#' @template pta
 #'
 #' @param object ([PredictionClassif] | [BenchmarkResult] | [ResampleResult])\cr
 #'   The binary class prediction object that will be evaluated.
@@ -34,8 +35,9 @@
 #' @export
 #' @return A 'ggplot2' object.
 #' @examples
-#' library(mlr3learners)
-#' library(ggplot2)
+#' library("mlr3")
+#' library("mlr3learners")
+#' library("ggplot2")
 #'
 #' # Setup the Fairness measure and tasks
 #' task = tsk("adult_train")$filter(1:500)
@@ -65,7 +67,8 @@ fairness_accuracy_tradeoff.PredictionClassif = function(object, fairness_measure
   assert_measure(fairness_measure)
   assert_measure(acc_measure)
   data = as.data.frame(t(object$score(list(acc_measure, fairness_measure), task = task)))
-  ggplot(data, aes_string(x = acc_measure$id, y = fairness_measure$id)) +
+
+  ggplot(data, aes(x = .data[[acc_measure$id]], y = .data[[fairness_measure$id]])) +
     geom_point()
 }
 
@@ -82,9 +85,9 @@ fairness_accuracy_tradeoff.BenchmarkResult = function(object, fairness_measure =
     data = rbind(data, insert_named(tmp, list("aggi" = 0, agg = "replication")), fill = TRUE)
   }
 
+
   ggplot(data,
-    aes_string(x = acc_measure$id, y = fairness_measure$id, colour = "learner_id", size = "aggi",
-      alpha = "aggi", pch = "agg")) +
+    aes(x = .data[[acc_measure$id]], y = .data[[fairness_measure$id]], colour = .data[["learner_id"]], size = .data[["aggi"]], alpha = .data[["aggi"]], pch = .data[["agg"]])) +
     geom_point() +
     scale_alpha(range = c(0.5, 1)) +
     scale_size(range = c(3, 6)) +
